⚠️⚠️⚠️ **IMPORTANT** ⚠️⚠️⚠️

The plugin was moved to the official Pelican plugin organization.

You can now find it here: https://github.com/pelican-plugins/minify

Also the package name changed to `pelican-minify`. Please read the docs.

New PyPI place is https://pypi.org/project/pelican-minify/.

⚠️⚠️⚠️ **IMPORTANT** ⚠️⚠️⚠️